@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 use Moo;
-use Types::Standard qw/Str Object Bool StrictNum Int HashRef ArrayRef/;
+use Types::Standard qw/Maybe Str Object Bool StrictNum Int HashRef ArrayRef/;
 use File::Copy;
 use File::Spec;
 use File::Temp;
@@ -27,11 +27,11 @@ PDF::Cropmarks - Add cropmarks to existing PDFs
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
 
@@ -153,6 +153,11 @@ false) and twoside is true (the default). Default to 0.1mm, which is
 appropriate for the common paper 80g/m2. You can do the math measuring
 a stack height and dividing by the number of sheets.
 
+=head2 title
+
+The (optional) job title to put on the markers. It defaults to the
+file basename.
+
 =cut
 
 has cropmark_length => (is => 'ro', isa => Str, default => sub { '12mm' });
@@ -260,7 +265,7 @@ sub _build_total_output_pages {
             return $total_input_pages + $missing;
         }
         elsif ($signature % 4) {
-            die "Signature must be 1 or a multiple of 4\n";
+            die "Signature must be 1 or a multiple of 4, but I got $signature";
         }
         else {
             my $missing = 0;
@@ -389,8 +394,9 @@ sub _build_out_pdf_object {
     my $self = shift;
     my $pdf = PDF::API2->new;
     my $now = POSIX::strftime(q{%Y%m%d%H%M%S+00'00'}, localtime(time()));
-    $pdf->info(Creator => 'PDF::Imposition',
+    $pdf->info(Creator => 'PDF::Cropmarks',
                Producer => 'PDF::API2',
+               Title => $self->title || $self->basename,
                CreationDate => $now,
                ModDate => $now);
     $pdf->mediabox($self->_paper_dimensions);
@@ -452,6 +458,8 @@ sub _round {
 
 has output_dimensions => (is => 'lazy', isa => ArrayRef);
 
+has title => (is => 'ro', isa => Maybe[Str]);
+
 sub _build_output_dimensions {
     my $self = shift;
     # get the first page
@@ -619,7 +627,8 @@ sub _import_page {
                      $offset_y + $inury + $crop_width);
     $text->text($marker);
 
-    my $text_marker = $self->basename . ' ' . $self->timestamp .
+    my $text_marker = ($self->title || $self->basename)
+      . ' ' . $self->timestamp .
       ' page ' . $page_number . $signature_mark;
     # and at the top and and the bottom add jobname + timestamp
     $text->translate(($inurx / 2) + $offset_x,
